//-----------------------------------------------------------
// UT2DWeap_Stinger
//
// Copyright 2008 Joe Bates
//
// This file is part of UT2D.
//
// UT2D is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// UT2D is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with UT2D.  If not, see <http://www.gnu.org/licenses/>.
//
// Last Modified: October 28, 2008
//-----------------------------------------------------------
class UT2DWeap_Stinger extends UTWeap_Stinger;

//DropFrom
function DropFrom(vector StartLocation, vector StartVelocity)
{
	local float Magnitude;
	
	StartLocation.Y = 0;
	
	Magnitude = vsize(StartVelocity);
	StartVelocity.Y = 0;
	StartVelocity = normal(StartVelocity) * Magnitude;
	
	super.DropFrom(StartLocation, StartVelocity);
}

//DrawWeaponCrosshair
simulated function DrawWeaponCrosshair(Hud HUD)
{
	local vector2d CrosshairSize;
	local float X, Y, PickupScale, ScreenX, ScreenY;
	local UTHUD	H;
	local UTPlayerController PC;
	local vector ViewLocation;
	
	H = UTHUD(HUD);
	if(H == none)
		return;
	
	PC = UTPlayerController(Instigator.Controller);
	if(PC == none)
		return;
		
	if(H.LastPickupTime > WorldInfo.TimeSeconds - 0.3)
	{
		if(H.LastPickupTime > WorldInfo.TimeSeconds - 0.15)
			PickupScale = (1 + 5 * (WorldInfo.TimeSeconds - H.LastPickupTime));
		else
			PickupScale = (1 + 5 * (H.LastPickupTime + 0.3 - WorldInfo.TimeSeconds));
	}
	else
		PickupScale = 1.0;

 	CrosshairSize.Y = CrosshairScaling * CrossHairCoordinates.VL * PickupScale * H.Canvas.ClipY / 768;
  	CrosshairSize.X = CrosshairSize.Y * (CrossHairCoordinates.UL / CrossHairCoordinates.VL);
	
	if(UT2DController_Player(PC) != none)
	{
		ViewLocation = H.Canvas.Project(UT2DController_Player(PC).LastViewLoc);
		X = ViewLocation.X + UT2DController_Player(PC).Look.X * H.Canvas.ClipY * 0.2;
		Y = ViewLocation.Y - UT2DController_Player(PC).Look.Z * H.Canvas.ClipY * 0.2;
	}
	else if(UT2DController_ConsolePlayer(PC) != none)
	{
		ViewLocation = H.Canvas.Project(UT2DController_ConsolePlayer(PC).LastViewLoc);
		X = ViewLocation.X + UT2DController_ConsolePlayer(PC).Look.X * H.Canvas.ClipY * 0.2;
		Y = ViewLocation.Y - UT2DController_ConsolePlayer(PC).Look.Z * H.Canvas.ClipY * 0.2;
	}
	
	ScreenX = X - (CrosshairSize.X * 0.5);
	ScreenY = Y - (CrosshairSize.Y * 0.5);
	
	if(CrosshairImage != none)
	{
		H.Canvas.DrawColor = H.BlackColor;
		H.Canvas.SetPos(ScreenX + 1, ScreenY + 1);
		H.Canvas.DrawTile(CrosshairImage, CrosshairSize.X, CrosshairSize.Y, CrossHairCoordinates.U, CrossHairCoordinates.V, CrossHairCoordinates.UL, CrossHairCoordinates.VL);
		
		CrosshairColor = H.bGreenCrosshair ? H.Default.LightGreenColor : Default.CrosshairColor;
		H.Canvas.DrawColor = (WorldInfo.TimeSeconds - LastHitEnemyTime < 0.3) ? H.RedColor : CrosshairColor;
		H.Canvas.SetPos(ScreenX, ScreenY);
		H.Canvas.DrawTile(CrosshairImage, CrosshairSize.X, CrosshairSize.Y, CrossHairCoordinates.U, CrossHairCoordinates.V, CrossHairCoordinates.UL, CrossHairCoordinates.VL);
	}
}

//DefaultProperties
defaultproperties
{
	DroppedPickupClass=class'UT2DDroppedPickup'
}